pub struct Assessment {
pub cve: Option<String>,
pub impacts: Option<Vec<String>>,
pub justification: Option<Justification>,
pub long_description: Option<String>,
pub related_uris: Option<Vec<RelatedUrl>>,
pub remediations: Option<Vec<Remediation>>,
pub short_description: Option<String>,
pub state: Option<String>,
pub vulnerability_id: Option<String>,
}Expand description
Assessment provides all information that is related to a single vulnerability for this product.
This type is not used in any activity, and only used as part of another schema.
Fields
cve: Option<String>Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability. Deprecated: Use vulnerability_id instead to denote CVEs.
impacts: Option<Vec<String>>Contains information about the impact of this vulnerability, this will change with time.
justification: Option<Justification>Justification provides the justification when the state of the assessment if NOT_AFFECTED.
long_description: Option<String>A detailed description of this Vex.
Holds a list of references associated with this vulnerability item and assessment. These uris have additional information about the vulnerability and the assessment itself. E.g. Link to a document which details how this assessment concluded the state of this vulnerability.
remediations: Option<Vec<Remediation>>Specifies details on how to handle (and presumably, fix) a vulnerability.
short_description: Option<String>A one sentence description of this Vex.
state: Option<String>Provides the state of this Vulnerability assessment.
vulnerability_id: Option<String>The vulnerability identifier for this Assessment. Will hold one of common identifiers e.g. CVE, GHSA etc.