Struct google_containeranalysis1_beta1::api::BatchCreateNotesRequest[][src]

pub struct BatchCreateNotesRequest {
    pub notes: Option<HashMap<String, Note>>,
}

Request to create notes in batch.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

notes: Option<HashMap<String, Note>>

Required. The notes to create, the key is expected to be the note ID. Max allowed length is 1000.