pub struct Detail {
pub cpe_uri: Option<String>,
pub description: Option<String>,
pub fixed_location: Option<VulnerabilityLocation>,
pub is_obsolete: Option<bool>,
pub max_affected_version: Option<Version>,
pub min_affected_version: Option<Version>,
pub package: Option<String>,
pub package_type: Option<String>,
pub severity_name: Option<String>,
pub source: Option<String>,
pub source_update_time: Option<DateTime<Utc>>,
pub vendor: Option<String>,
}Expand description
Identifies all appearances of this vulnerability in the package for a specific distro/location. For example: glibc in cpe:/o:debian:debian_linux:8 for versions 2.1 - 2.2
This type is not used in any activity, and only used as part of another schema.
Fields
cpe_uri: Option<String>Required. The CPE URI in cpe format in which the vulnerability manifests. Examples include distro or storage location for vulnerable jar.
description: Option<String>A vendor-specific description of this note.
fixed_location: Option<VulnerabilityLocation>The fix for this specific package version.
is_obsolete: Option<bool>Whether this detail is obsolete. Occurrences are expected not to point to obsolete details.
max_affected_version: Option<Version>The max version of the package in which the vulnerability exists.
min_affected_version: Option<Version>The min version of the package in which the vulnerability exists.
package: Option<String>Required. The name of the package where the vulnerability was found.
package_type: Option<String>The type of package; whether native or non native(ruby gems, node.js packages etc).
severity_name: Option<String>The severity (eg: distro assigned severity) for this vulnerability.
source: Option<String>The source from which the information in this Detail was obtained.
source_update_time: Option<DateTime<Utc>>The time this information was last changed at the source. This is an upstream timestamp from the underlying information source - e.g. Ubuntu security tracker.
vendor: Option<String>The name of the vendor of the product.