pub struct GenericSignedAttestation {
pub content_type: Option<String>,
pub serialized_payload: Option<Vec<u8>>,
pub signatures: Option<Vec<Signature>>,
}Expand description
An attestation wrapper that uses the Grafeas Signature message. This attestation must define the serialized_payload that the signatures verify and any metadata necessary to interpret that plaintext. The signatures should always be over the serialized_payload bytestring.
This type is not used in any activity, and only used as part of another schema.
Fields
content_type: Option<String>Type (for example schema) of the attestation payload that was signed. The verifier must ensure that the provided type is one that the verifier supports, and that the attestation payload is a valid instantiation of that type (for example by validating a JSON schema).
serialized_payload: Option<Vec<u8>>The serialized payload that is verified by one or more signatures. The encoding and semantic meaning of this payload must match what is set in content_type.
signatures: Option<Vec<Signature>>One or more signatures over serialized_payload. Verifier implementations should consider this attestation message verified if at least one signature verifies serialized_payload. See Signature in common.proto for more details on signature structure and verification.