pub struct InToto {
pub expected_command: Option<Vec<String>>,
pub expected_materials: Option<Vec<ArtifactRule>>,
pub expected_products: Option<Vec<ArtifactRule>>,
pub signing_keys: Option<Vec<SigningKey>>,
pub step_name: Option<String>,
pub threshold: Option<i64>,
}Expand description
This contains the fields corresponding to the definition of a software supply chain step in an in-toto layout. This information goes into a Grafeas note.
This type is not used in any activity, and only used as part of another schema.
Fields
expected_command: Option<Vec<String>>This field contains the expected command used to perform the step.
expected_materials: Option<Vec<ArtifactRule>>The following fields contain in-toto artifact rules identifying the artifacts that enter this supply chain step, and exit the supply chain step, i.e. materials and products of the step.
expected_products: Option<Vec<ArtifactRule>>no description provided
signing_keys: Option<Vec<SigningKey>>This field contains the public keys that can be used to verify the signatures on the step metadata.
step_name: Option<String>This field identifies the name of the step in the supply chain.
threshold: Option<i64>This field contains a value that indicates the minimum number of keys that need to be used to sign the step’s in-toto link.