Struct google_containeranalysis1_beta1::api::BatchCreateOccurrencesResponse [−][src]
Response for creating occurrences in batch.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- occurrences batch create projects (response)
Fields
occurrences: Option<Vec<Occurrence>>The occurrences that were created.